package cc.idl;

/**
* cc/idl/UDPSvrHolder.java .
* Generated by the IDL-to-Java compiler (portable), version "3.1"
* from UDPSvr.idl
* Friday, July 25, 2003 1:35:12 PM EDT
*/

public final class UDPSvrHolder implements org.omg.CORBA.portable.Streamable
{
  public cc.idl.UDPSvr value = null;

  public UDPSvrHolder ()
  {
  }

  public UDPSvrHolder (cc.idl.UDPSvr initialValue)
  {
    value = initialValue;
  }

  public void _read (org.omg.CORBA.portable.InputStream i)
  {
    value = cc.idl.UDPSvrHelper.read (i);
  }

  public void _write (org.omg.CORBA.portable.OutputStream o)
  {
    cc.idl.UDPSvrHelper.write (o, value);
  }

  public org.omg.CORBA.TypeCode _type ()
  {
    return cc.idl.UDPSvrHelper.type ();
  }

}
