package cc.monitors;

public abstract class AbstractMonitor{
	protected int eventCounter = 0;
	protected boolean finished = false;
	protected boolean firstTime = true;

	public void terminate(){
		finished = true;
	}

	public abstract void update(Event event);

	public abstract void evaluate();
}


