module cc{
module idl{
    interface UDPSvr{
        long    request (in string host,  in long port, in long size, in long delay);
        void 	requestPackets (in long id, in string listOfPackets);

        void    setSize(in long id, in long Size);
        void    setDelay(in long id, in long Delay);

        long    getDelay(in long id);
        long    getSize(in long id);
        void    stop(in long id);
        void    alive(in long id);
    };
};
};
