package cc.idl;


/**
* cc/idl/UDPSvrOperations.java .
* Generated by the IDL-to-Java compiler (portable), version "3.1"
* from UDPSvr.idl
* Friday, July 25, 2003 1:35:12 PM EDT
*/

public interface UDPSvrOperations 
{
  int request (String host, int port, int size, int delay);
  void requestPackets (int id, String listOfPackets);
  void setSize (int id, int Size);
  void setDelay (int id, int Delay);
  int getDelay (int id);
  int getSize (int id);
  void stop (int id);
  void alive (int id);
} // interface UDPSvrOperations
