package cc.idl;


/**
* cc/idl/UDPSvr.java .
* Generated by the IDL-to-Java compiler (portable), version "3.1"
* from UDPSvr.idl
* Friday, July 25, 2003 1:35:12 PM EDT
*/

public interface UDPSvr extends UDPSvrOperations, org.omg.CORBA.Object, org.omg.CORBA.portable.IDLEntity 
{
} // interface UDPSvr
